# TimeLine Eprints timeline Plugin (MIT Simile Timeline API)
# Part of EPrints3 
# Distributed under GPL Licience
#
# Package Written by David Tarrant (dct05r@ecs.soton.ac.uk)
#
# This plugin also requires TimeLineXML.pm to be present


package EPrints::Plugin::Export::TimeLine;

use EPrints::Plugin::Export;

@ISA = ( "EPrints::Plugin::Export" );

use Unicode::String qw(latin1);

use strict;

sub new
{
	my( $class, %opts ) = @_;

	my $self = $class->SUPER::new( %opts );

	$self->{name} = "TimeLine";
	$self->{accept} = [ 'list/eprint' ];
	$self->{visible} = "all";
	$self->{suffix} = ".html";
	$self->{mimetype} = "text/html";

	return $self;
}

sub output_list
{
	my( $plugin, %opts ) = @_;

	my $list = $opts{list};

	my $session = $plugin->{session};

	my $html = $session->make_element( "html",
		"xmlns"=>"http://www.w3.org/1999/xhtml" );

	my $head = $session->make_element("head");
	
	my $style = $session->make_element("style",
		"type"=>"text/css",
		"media"=>"screen");
	my $style_text = "
	body,td,th {
		font-family: Arial, sans-serif;
		font-size: 10pt;
	}
	.charttext {
		font-family: Verdana, sans-serif;
		font-size: 8pt;
	}
	
	body {
		background-color: #FFFFFF;
	}
	.smalltext {font-size:8pt; font-family:Arial, Helvetica, sans-serif}
	.white-text {color: #FFFFFF}
	.maroonhead {font-size: 18pt; color:#990000;}
	.boldtext {font-weight: bold}
	.style4 {font-size: 8pt}
	";
	$style->appendChild( $session->make_text( $style_text ) );
	$head->appendChild( $style );
	
	$html->appendChild( $head );

	my $url = $session->get_full_url();

	my $meta = $session->make_element("meta",
		"http-equiv"=>"content-type", 
		"content"=>"text/html; charset=utf-8");
	$head->appendChild( $meta );

	$head->appendChild( $session->render_data_element(
		4,
		"title",
		"Eprints TimeLine Exporter") );

	my $script1 = $session->make_element("script",
		"src"=>"http://simile.mit.edu/timeline/api/timeline-api.js",
		"type"=>"text/javascript");

	$head->appendChild ($script1);


	# build script2 as text	
	my $script2 = $session->make_element("script",
		"type"=>"text/javascript");

	$url =~ s/TimeLine/TimeLineXML/g;

	my $script2_text = "\t\tvar tl;\n";
	$script2_text .= "\t\tfunction onLoad() {\n";
	$script2_text .= "\t\tvar eventSource = new Timeline.DefaultEventSource();\n";
	$script2_text .= "\t\tvar d = Timeline.DateTime.parseGregorianDateTime(Date());\n";
	$script2_text .= "\t\tvar theme = Timeline.ClassicTheme.create();\n";
	$script2_text .= "\t\ttheme.event.bubble.width = 220;\n";
	$script2_text .= "\t\ttheme.event.bubble.height = 300;\n";
	$script2_text .= "\n";
	$script2_text .= "\t\t\tvar bandInfos = [\n";
	$script2_text .= "\t\t\t\tTimeline.createBandInfo({\n";
	$script2_text .= "\t\t\t\t\teventSource:    eventSource,\n";
	$script2_text .= "\t\t\t\t\tdate:	d,\n";
	$script2_text .= "\t\t\t\t\twidth:          \"70%\", \n";
	$script2_text .= "\t\t\t\t\tintervalUnit:   Timeline.DateTime.MONTH, \n";
	$script2_text .= "\t\t\t\t\tintervalPixels: 100\n";
	$script2_text .= "\t\t\t\t}),\n";
	$script2_text .= "\t\t\t\tTimeline.createBandInfo({\n";
	$script2_text .= "\t\t\t\t\teventSource:    eventSource,\n";
        $script2_text .= "\t\t\t\t\tdate:	d,\n";
	$script2_text .= "\t\t\t\t\twidth:          \"30%\", \n";
	$script2_text .= "\t\t\t\t\tintervalUnit:   Timeline.DateTime.YEAR, \n";
	$script2_text .= "\t\t\t\t\tintervalPixels: 200\n";
	$script2_text .= "\t\t\t\t})\n";
	$script2_text .= "\t\t\t];\n";
	$script2_text .= "\t\t\tbandInfos[1].syncWith = 0;\n";
	$script2_text .= "\t\t\tbandInfos[1].highlight = true;\n";
	$script2_text .= "\n";
	$script2_text .= "\t\t\ttl = Timeline.create(document.getElementById(\"my-timeline\"), bandInfos);\n";
	$script2_text .= "\t\t\ttl.loadXML(\"$url\", function(xml, url) { eventSource.loadXML(xml, url); });\n";
	$script2_text .= "\t\t}\n";
	$script2_text .= "\n";
	$script2_text .= "\t\tvar resizeTimerID = null;\n";
	$script2_text .= "\t\tfunction onResize() {\n";
	$script2_text .= "\t\t\tif (resizeTimerID == null) {\n";
	$script2_text .= "\t\t\t\tresizeTimerID = window.setTimeout(function() {\n";
	$script2_text .= "\t\t\t\tresizeTimerID = null;\n";
	$script2_text .= "\t\t\t\ttl.layout();\n";
	$script2_text .= "\t\t\t\t}, 500);\n";
	$script2_text .= "\t\t\t}\n";
	$script2_text .= "\t\t}\n";
	
	$script2->appendChild( $session->make_text( $script2_text ) );
	$head->appendChild($script2);

	my $body = $session->make_element("body",
		"onload"=>"onLoad()", 
		"onresize"=>"onResize()");

	my $div = $session->make_element("div",
		"align"=>"center");

	my $div1 = $session->make_element("div",
		"id"=>"my-timeline",
		"style"=>"width: 80%; height: 400px; border: 1px solid #aaa");

	my $heading = $session->make_element( "h1" );
	$heading->appendChild ($session->make_text ( "EPrints3 TimeLine Exporter" ));
	my $hr = $session->make_element( "hr" );
	$heading->appendChild( $hr );
	$body->appendChild( $heading );
	$div->appendChild( $div1 );
	$body->appendChild( $div );
	$html->appendChild( $body );
		

	my $timeline = <<END;
<?xml version="1.0" encoding="utf-8" ?>
END
	$timeline .= EPrints::XML::to_string( $html );
	EPrints::XML::dispose( $html );

	if( defined $opts{fh} )
	{
		print {$opts{fh}} $timeline;
		return undef;
	} 

	return $timeline;
}

1;

